summaryrefslogtreecommitdiff
path: root/include/mailutils/folder.h
diff options
context:
space:
mode:
authorSergey Poznyakoff <gray@gnu.org>2019-03-26 21:41:09 +0200
committerSergey Poznyakoff <gray@gnu.org>2019-03-26 21:41:09 +0200
commit60c5545ba8a5c9f4038b5587c96c19b80f538831 (patch)
tree13ecd0d40286e43a37934b0ddd07c1e898fb4d75 /include/mailutils/folder.h
parent5b69ce81ec29afeea0e67bd8b0f0b193a7b0c022 (diff)
downloadmailutils-60c5545ba8a5c9f4038b5587c96c19b80f538831.tar.gz
mailutils-60c5545ba8a5c9f4038b5587c96c19b80f538831.tar.bz2
Consistently use the term 'depth' when referring to directory nesting depth
* include/mailutils/folder.h (mu_list_response): Rename 'level' to 'depth'. All uses updated.
Diffstat (limited to 'include/mailutils/folder.h')
-rw-r--r--include/mailutils/folder.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/include/mailutils/folder.h b/include/mailutils/folder.h
index 4ca4b92ee..ceb54dd62 100644
--- a/include/mailutils/folder.h
+++ b/include/mailutils/folder.h
@@ -27,9 +27,9 @@ extern "C" {
struct mu_list_response
{
int type; /* MU_FOLDER_ATTRIBUTE_.* flags */
- int level;
- int separator;
- char *name;
+ int depth; /* Item depth within the hierarchy */
+ int separator; /* Directory separator character */
+ char *name; /* Item name */
mu_record_t format; /* Associated mailbox format record */
};
@@ -66,7 +66,8 @@ struct mu_folder_scanner
char const *refname; /* Reference name */
void *pattern; /* Matching pattern */
int match_flags; /* Matching flags */
- size_t max_level; /* Max. nesting level to descend */
+ size_t max_depth; /* Max. depth to descend
+ (1-based, 0 means 'unlimited') */
mu_folder_enumerate_fp enumfun; /* Enumeration function */
void *enumdata; /* Data for enumfun */
mu_list_t records; /* List of allowed records */

Return to:

Send suggestions and report system problems to the System administrator.